@@ -7,14 +7,14 @@
 #' @param factor Quoted name of the factor variable used to differentiate the data projects in the test.
 #' @param reduced_model Quoted or unquoted reduced model used in the test.  The variables mentioned in the model must exist in the provided data frame. X and Y sides of the model must be separated by "~".
 #' @param filter Optional argument. If supplied with levels present in \code{factor}, only these levels will be used in the test. \code{NA}.
+#' @param gray_scale If \code{TRUE} a gray scale will be used in the plots. Default: \code{FALSE}.
+#' @param signif Numeric value for the significance level used in the test. Default: \code{0.05}.
+#' @param font font family used in the plots. Can be either \code{"serif"} for Times New Roman or \code{"sans"} for arial unicode MS. Default: \code{"serif"}.
 #' @param output Defines the type of output. If \code{"table"} an anova table with the identity of model test is provided,
 #' if \code{"plot"} a ggplot plot/object representing the test is created,
 #' if \code{"table_plot"}, both anova table and plot are provided, and if \code{"full"},
 #' a list is provided, with details on the dummies variables created, the reduced and complete models,
 #' the anova table and the plot. Default: \code{"table"}
-#' @param gray_scale If \code{TRUE} a gray scale will be used in the plots. Default: \code{FALSE}.
-#' @param signif Numeric value for the significance level used in the test. Default: \code{0.05}.
-#' @param font font family used in the plots. Can be either \code{"serif"} for Times New Roman or \code{"sans"} for arial unicode MS. Default: \code{"serif"}.
 #' @return A data frame, a ggplot object, or a list, varying according to the \code{output} argument.
 #' 
 #' @references 
@@ -24,7 +24,7 @@
 #' @examples
 #' library(forestmangr)
 #' data("exfm13")
-#' head(exfm13, 10)
+#' exfm13
 #' 
 #' # The objective is to know if the diameter's behavior is similar among 3 species.
 #' # For this we'll use a quadratic model. We'll use nitrogen (N) as our X variable.
@@ -63,15 +63,15 @@
 #' # the "Sucupira-preta" and "Vinhatico" species,
 #' # and a second model is needed to explain the Pequi Variable.
 #'
-#' # It's possible to apply a gray scale to the plots, and also change it's font to arial:
+#' # It's possible to apply a color scale to the plots, and also change it's font to arial:
 #' 
-#' ident_model(exfm13, "species", dbh ~  N + N2,output="plot",gray_scale=TRUE,font="sans")
+#' ident_model(exfm13, "species", dbh ~  N + N2,output="plot",gray_scale=FALSE,font="sans")
 #'
 #' @author Sollano Rabelo Braga \email{sollanorb@@gmail.com}
 #' @author Marcio leles Romarco de Oliveira \email{marcioromarco@@gmail.com}
 
 
-ident_model <- function(df, factor, reduced_model, filter = NA, output = "table", gray_scale = FALSE, signif = 0.05, font="serif" ){
+ident_model <- function(df, factor, reduced_model, filter = NA, gray_scale = TRUE, signif = 0.05, font="serif", output = "table" ){
   # ####
   ..eq.label..<-..rr.label..<-NULL
   # ####
@@ -105,7 +105,7 @@ ident_model <- function(df, factor, reduced_model, filter = NA, output = "table"
   }
   
   # Se filter nao for fornecido, criar objeto que dplyr::group_by ignora, sem causar erro
-  if(missing(filter)||is.null(filter)||is.na(filter)||filter==F||filter==""){
+  if(missing(filter)||all(is.null(filter))||all(is.na(filter))||all(filter==F)||all(filter=="")){
     filter <- NULL
     # Se groups for fornecido verificar se todos os nomes de variaveis fornecidos existem no dado  
   }else if(!is.character(filter)){ 
@@ -141,8 +141,8 @@ ident_model <- function(df, factor, reduced_model, filter = NA, output = "table"
     stop( "'output' must be character", call.=F)
   }else if(length(output)!=1){
     stop("Length of 'output' must be 1", call.=F)
-  }else if(! output %in% c('full', 'table_plot', 'plot', 'table') ){ 
-  stop("'output' must be equal to 'full', 'table_plot', 'plot' or 'table' ", call. = F) 
+  }else if(! output %in% c('table', 'plot', 'table_plot', 'full' ) ){ 
+  stop("'output' must be equal to 'table', 'plot', 'table_plot' or 'full' ", call. = F) 
   }
   
   # ####
